A sample dataset of input regression results based on machine-level accurate cumulative normal values.
Rather than just typing in a few digits of the 2.5
the norminverse function in RATS was used to create sample-case betas which are exact
Arguments
Format
csv format file with 4 variables (beta, n0, n1, n2) and 120 rows